"""
marketplace_bundle automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .marketplace_object import MarketplaceObject
from .marketplace_bundle_config import MarketplaceBundleConfig


class MarketplaceBundle(MarketplaceObject):
    config: Optional[MarketplaceBundleConfig] = Field(default=None, alias="config")
    pass


