"""
backend_role automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


# This object represents a role, every user is assigned to a role and all scopes of the role are automatically attached to the user
class BackendRole(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    category_id: Optional[int] = Field(default=None, alias="categoryId")
    name: Optional[str] = Field(default=None, alias="name")
    scopes: Optional[List[str]] = Field(default=None, alias="scopes")
    pass


