"""
backend_user_create automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_user import BackendUser


class BackendUserCreate(BackendUser):
    password: Optional[str] = Field(default=None, alias="password")
    pass


